
#line 3 "<stdout>"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer QuestLoader_create_buffer
#define yy_delete_buffer QuestLoader_delete_buffer
#define yy_flex_debug QuestLoader_flex_debug
#define yy_init_buffer QuestLoader_init_buffer
#define yy_flush_buffer QuestLoader_flush_buffer
#define yy_load_buffer_state QuestLoader_load_buffer_state
#define yy_switch_to_buffer QuestLoader_switch_to_buffer
#define yyin QuestLoaderin
#define yyleng QuestLoaderleng
#define yylex QuestLoaderlex
#define yylineno QuestLoaderlineno
#define yyout QuestLoaderout
#define yyrestart QuestLoaderrestart
#define yytext QuestLoadertext
#define yywrap QuestLoaderwrap
#define yyalloc QuestLoaderalloc
#define yyrealloc QuestLoaderrealloc
#define yyfree QuestLoaderfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE QuestLoaderrestart(QuestLoaderin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t QuestLoaderleng;

extern FILE *QuestLoaderin, *QuestLoaderout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up QuestLoadertext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up QuestLoadertext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via QuestLoaderrestart()), so that the user can continue scanning by
	 * just pointing QuestLoaderin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when QuestLoadertext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t QuestLoaderleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow QuestLoaderwrap()'s to do buffer switches
 * instead of setting up a fresh QuestLoaderin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void QuestLoaderrestart (FILE *input_file  );
void QuestLoader_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE QuestLoader_create_buffer (FILE *file,int size  );
void QuestLoader_delete_buffer (YY_BUFFER_STATE b  );
void QuestLoader_flush_buffer (YY_BUFFER_STATE b  );
void QuestLoaderpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void QuestLoaderpop_buffer_state (void );

static void QuestLoaderensure_buffer_stack (void );
static void QuestLoader_load_buffer_state (void );
static void QuestLoader_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER QuestLoader_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE QuestLoader_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE QuestLoader_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE QuestLoader_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *QuestLoaderalloc (yy_size_t  );
void *QuestLoaderrealloc (void *,yy_size_t  );
void QuestLoaderfree (void *  );

#define yy_new_buffer QuestLoader_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        QuestLoaderensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            QuestLoader_create_buffer(QuestLoaderin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        QuestLoaderensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            QuestLoader_create_buffer(QuestLoaderin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *QuestLoaderin = (FILE *) 0, *QuestLoaderout = (FILE *) 0;

typedef int yy_state_type;

extern int QuestLoaderlineno;

int QuestLoaderlineno = 1;

extern char *QuestLoadertext;
#define yytext_ptr QuestLoadertext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up QuestLoadertext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	QuestLoaderleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 107
#define YY_END_OF_BUFFER 108
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[851] =
    {   0,
        0,    0,  108,  106,  105,  103,  106,  106,  106,  106,
      106,  100,   95,  106,   94,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,   82,  101,  101,
       80,   81,  101,  105,    0,  104,    0,    0,  102,  100,
       93,   97,   98,   96,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,   90,  101,  101,  101,  101,  101,
      101,  101,  101,   74,  101,  101,   99,   77,   89,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,

      101,  101,   83,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,   79,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,   73,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,   91,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,   92,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,    1,   78,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,

      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,   75,  101,  101,  101,  101,  101,  101,
       85,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,

      101,  101,  101,   16,  101,  101,   14,  101,   15,   84,
       86,   88,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,   76,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,   20,   17,  101,
       13,  101,   87,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,   29,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,

      101,  101,  101,  101,    2,  101,  101,  101,   65,   69,
      101,  101,   60,  101,   66,  101,  101,  101,  101,  101,
      101,   51,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,    7,    4,  101,  101,  101,    8,  101,
      101,   46,   45,  101,  101,  101,  101,  101,  101,   38,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,   62,  101,  101,
      101,  101,  101,  101,  101,  101,   19,  101,  101,  101,
      101,  101,  101,    3,  101,  101,  101,  101,  101,  101,
      101,  101,  101,   41,  101,   31,  101,  101,  101,  101,

      101,  101,  101,  101,  101,  101,  101,  101,   71,  101,
      101,  101,  101,  101,   61,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,   44,   18,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,   55,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,   49,  101,  101,  101,  101,  101,  101,  101,  101,

      101,  101,  101,  101,  101,  101,  101,  101,  101,   10,
      101,   12,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,    6,
      101,  101,  101,  101,  101,   34,  101,  101,  101,  101,
       35,  101,   30,  101,  101,  101,  101,  101,  101,  101,
       58,   63,  101,  101,   70,  101,  101,  101,  101,  101,
      101,  101,  101,  101,   21,  101,  101,  101,    9,  101,
      101,   37,  101,  101,  101,  101,   43,  101,  101,  101,

      101,  101,   57,  101,  101,  101,  101,   68,  101,  101,
      101,  101,  101,   25,  101,  101,  101,  101,   32,  101,
      101,   39,  101,   36,   47,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,    5,  101,   33,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,   54,   50,  101,  101,  101,
      101,  101,   11,  101,  101,  101,  101,  101,  101,  101,
       72,  101,   64,  101,   52,  101,  101,  101,  101,   42,
      101,  101,  101,  101,  101,  101,  101,   53,   56,  101,
      101,  101,  101,  101,   24,  101,  101,  101,  101,  101,

      101,  101,   40,  101,  101,  101,   59,  101,  101,  101,
      101,   48,  101,  101,   67,  101,  101,   22,   26,  101,
      101,  101,  101,  101,  101,  101,  101,  101,  101,  101,
      101,  101,  101,  101,  101,  101,   28,  101,  101,  101,
      101,  101,   23,  101,  101,  101,  101,  101,   27,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    4,    5,    1,    1,    6,    1,
        1,    1,    7,    1,    8,    1,    1,    9,   10,   11,
       12,   12,   13,   14,   12,   12,   12,    1,    1,   15,
       16,   17,    1,    1,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
        1,    1,    1,    1,   44,    1,   43,   43,   43,   43,

       45,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   46,   43,   47,   48,   49,   43,   43,   43,
       43,   43,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[50] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    3,    3,
        3,    3,    3,    3,    1,    1,    1,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    3,    4,    4,    4,    4,    4
    } ;

static yyconst flex_int16_t yy_base[856] =
    {   0,
        0,    0,  900,  901,  897,  901,  895,    0,  891,   41,
       47,   56,  880,  879,  878,   42,   54,   49,   56,  854,
       57,    0,   57,   54,  857,   66,  853,    0,   58,   68,
        0,    0,  841,  887,  885,  901,    0,  881,  880,   95,
      901,  901,  901,  901,    0,  856,  863,  861,  845,  845,
      836,  861,  848,   90,  841,  840,  843,  852,   86,  841,
      851,  840,  829,  849,    0,  833,  832,   92,  844,  847,
      844,   95,  833,    0,  824,  816,    0,    0,    0,  842,
      841,  832,  823,  821,  822,  828,  831,  826,  833,   68,
      830,  829,  815,  816,  817,  809,  814,  799,  806,  804,

      796,  802,    0,  794,  818,  800,  800,  814,  811,  814,
      809,  793,  807,  806,  780,    0,  806,  805,  786,  805,
      793,  790,  791,  778,  776,  786,  782,  780,  796,  769,
      775,  767,  788,    0,  772,  771,  763,   87,  764,  768,
      760,  766,  765,  779,  771,  757,  764,  779,  752,    0,
      747,  769,  749,  770,  771,  768,  767,  744,  743,  742,
      764,  740,  757,  747,  755,  736,  742,    0,  760,  755,
      742,  744,  756,  729,  754,   52,  727,  726,  733,  724,
      723,  722,  730,  735,    0,    0,  737,  726,  724,  723,
      729,  732,  731,  113,  724,   96,  722,  733,  716,  722,

      733,  721,  714,  710,  726,  716,  711,  715,  110,  730,
      119,  109,  706,  715,  714,  139,  702,  712,  706,  699,
      713,  708,  715,  695,  694,  698,  688,  710,  103,  705,
      691,  688,  706,  693,  700,  684,  111,  683,  701,  696,
      699,  687,  687,    0,  692,  691,  690,  673,  682,  120,
        0,  695,   66,  677,  681,  133,  688,  668,  662,  683,
      680,  657,  663,  662,  661,  132,  659,  658,  130,  673,
      656,  671,  144,  661,  647,  660,  666,  644,  652,  654,
      641,  662,  661,  651,  648,  650,  656,  656,  638,  644,
      657,  639,  629,  654,  649,  648,  628,  637,  641,  647,

      635,  631,  635,    0,  626,  620,    0,  638,    0,  631,
        0,    0,  637,  631,  635,  624,  624,  633,  617,  633,
      617,  612,  614,  610,  624,  623,  607,  620,  621,  619,
      614,  616,  616,  598,  614,  615,  608,  595,  614,  605,
      149,  604,  597,  610,    0,  596,  595,  595,  594,  585,
      600,  599,  591,  589,  596,  584,  579,  582,  581,  592,
      582,  574,  566,  573,  576,  578,  562,    0,    0,  568,
        0,  568,    0,  559,  566,  579,  579,  577,  554,  560,
      561,  573,  568,    0,  575,  562,  561,  572,  567,  564,
      558,  557,  556,  554,  561,  546,  542,  558,  550,  543,

      540,  558,  557,  537,    0,  536,  528,  533,    0,    0,
      534,  534,    0,  530,  523,  537,  543,  526,  519,  544,
      517,    0,  516,  533,  521,  526,  534,  518,  510,  516,
      515,  519,  509,    0,    0,  523,  506,  510,    0,  514,
      516,    0,    0,  524,  512,  520,  497,  519,  501,    0,
      509,  500,  492,  506,  490,  496,  488,  498,  495,  485,
      491,  152,  497,  482,  499,  502,  493,    0,  491,  485,
      490,  477,  499,  153,  480,  494,    0,  471,  482,  487,
      468,  469,  489,    0,  478,  134,  464,  476,  478,  477,
      468,  459,  469,    0,  479,    0,  456,  465,  477,  464,

      452,  467,  450,  456,  466,  456,  470,  467,    0,  452,
      465,  455,  459,  448,    0,  465,  438,  439,  462,  446,
      459,  455,  441,  441,  430,  442,  442,  438,  448,  446,
      426,  437,  429,    0,    0,  421,  442,  430,  444,  430,
      434,  421,  414,  439,  438,  429,  428,  411,  421,  425,
      413,  415,  152,  417,  427,  410,  419,  411,  417,  398,
      408,  420,  412,  408,    0,  399,  418,  414,  412,  411,
      388,  399,  397,  407,  386,  394,  382,  407,  389,  403,
      391,  399,  387,  384,  383,  386,  385,  371,  370,  369,
      386,    0,  385,  392,  389,  386,  371,  369,  361,  367,

      373,  352,   41,   54,   77,  136,  130,  150,  156,    0,
      151,    0,  168,  161,  159,  175,  161,  160,  159,  175,
      177,  163,  182,  164,  180,  182,  183,  165,  176,  181,
      176,  180,  173,  189,  169,  188,  173,  190,  195,  186,
      201,  194,  195,  185,  187,  195,  184,  207,  185,    0,
      209,  207,  195,  213,  195,    0,  189,  212,  198,  201,
        0,  219,    0,  216,  221,  214,  205,  220,  212,  215,
        0,    0,  208,  214,    0,  216,  218,  218,  215,  220,
      221,  235,  217,  211,    0,  234,  224,  236,    0,  222,
      225,    0,  224,  221,  219,  227,    0,  224,  231,  236,

      224,  230,    0,  226,  229,  241,  252,    0,  238,  253,
      253,  256,  243,    0,  261,  245,  259,  247,    0,  246,
      242,    0,  259,    0,    0,  253,  249,  268,  267,  257,
      258,  262,  271,  258,  278,  265,  276,  275,  263,  283,
      258,    0,  267,    0,  271,  274,  262,  270,  282,  274,
      278,  289,  294,  272,  292,    0,    0,  274,  294,  280,
      283,  299,    0,  298,  300,  299,  301,  287,  281,  300,
        0,  291,    0,  293,    0,  292,  312,  294,  300,    0,
      311,  305,  299,  294,  317,  307,  302,    0,    0,  320,
      299,  304,  302,  326,    0,  305,  314,  310,  326,  321,

      306,  320,    0,  328,  335,  324,    0,  320,  312,  327,
      321,    0,  324,  327,    0,  341,  340,    0,    0,  334,
      339,  335,  344,  349,  349,  332,  335,  349,  346,  355,
      339,  343,  356,  341,  347,  342,    0,  336,  359,  363,
      348,  342,    0,  341,  348,  351,  366,  354,    0,  901,
      389,  390,  394,  396,  398
    } ;

static yyconst flex_int16_t yy_def[856] =
    {   0,
      850,    1,  850,  850,  850,  850,  851,  852,  853,  850,
      850,  850,  850,  850,  850,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  850,  851,  850,  855,  853,  850,  850,
      850,  850,  850,  850,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  855,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,    0,
      850,  850,  850,  850,  850
    } ;

static yyconst flex_int16_t yy_nxt[951] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   12,
       12,   12,   12,   12,   13,   14,   15,   16,   17,   18,
       19,   20,   21,   22,   22,   22,   22,   22,   22,   23,
       24,   25,   26,   27,   28,   29,   30,   22,   22,   22,
       31,   32,   22,    4,   22,   33,   22,   22,   22,   40,
       40,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,  209,  210,   41,   40,   40,   40,   40,   40,   40,
       46,   50,   47,   52,   59,   63,   48,   55,   49,   51,
       53,   56,   61,   66,  642,  126,   64,   67,   62,  127,
       57,   60,   54,   73,   70,   71,  313,  643,  314,   74,

       68,   72,   75,   40,   40,   40,   40,   40,   40,   86,
       87,   95,  172,  104,   96,  109,  235,  173,  250,   88,
      644,  236,   89,  105,   90,  237,  260,  110,  310,  111,
      112,  226,  296,  287,  227,  228,  297,  251,  229,  288,
      253,  230,  298,  261,  254,  231,  255,  311,  232,  256,
      317,  257,  233,  328,  258,  259,  265,  645,  646,  266,
      332,  267,  268,  329,  269,  318,  333,  270,  337,  507,
      531,  647,  271,  272,  273,  338,  274,  532,  402,  593,
      339,  403,  519,  520,  521,  648,  508,  649,  594,  650,
      651,  652,  653,  654,  655,  656,  657,  658,  659,  660,

      661,  662,  663,  664,  665,  666,  667,  669,  670,  671,
      672,  668,  673,  674,  675,  676,  677,  678,  679,  680,
      681,  682,  683,  684,  685,  686,  687,  688,  689,  690,
      691,  692,  693,  694,  695,  696,  697,  698,  699,  700,
      701,  702,  703,  704,  705,  706,  707,  708,  709,  710,
      711,  712,  713,  714,  715,  716,  717,  718,  719,  720,
      721,  722,  723,  724,  725,  726,  727,  728,  729,  730,
      731,  732,  733,  734,  735,  736,  737,  738,  739,  741,
      742,  743,  744,  745,  746,  747,  748,  749,  750,  751,
      752,  753,  754,  740,  755,  756,  757,  758,  759,  760,

      761,  762,  763,  764,  765,  766,  767,  768,  769,  770,
      771,  772,  773,  774,  775,  776,  777,  778,  779,  780,
      781,  782,  783,  784,  785,  786,  787,  788,  789,  790,
      791,  792,  793,  794,  795,  796,  797,  798,  799,  800,
      801,  802,  803,  804,  805,  806,  807,  808,  809,  810,
      811,  812,  813,  814,  815,  816,  817,  818,  819,  820,
      821,  822,  823,  824,  825,  826,  827,  828,  829,  830,
      831,  832,  833,  834,  835,  836,  837,  838,  839,  840,
      841,  842,  843,  844,  845,  846,  847,  848,  849,   35,
       35,   35,   35,   37,   38,  641,   38,   38,   45,   45,

       77,   77,  640,  639,  638,  637,  636,  635,  634,  633,
      632,  631,  630,  629,  628,  627,  626,  625,  624,  623,
      622,  621,  620,  619,  618,  617,  616,  615,  614,  613,
      612,  611,  610,  609,  608,  607,  606,  605,  604,  603,
      602,  601,  600,  599,  598,  597,  596,  595,  592,  591,
      590,  589,  588,  587,  586,  585,  584,  583,  582,  581,
      580,  579,  578,  577,  576,  575,  574,  573,  572,  571,
      570,  569,  568,  567,  566,  565,  564,  563,  562,  561,
      560,  559,  558,  557,  556,  555,  554,  553,  552,  551,
      550,  549,  548,  547,  546,  545,  544,  543,  542,  541,

      540,  539,  538,  537,  536,  535,  534,  533,  530,  529,
      528,  527,  526,  525,  524,  523,  522,  518,  517,  516,
      515,  514,  513,  512,  511,  510,  509,  506,  505,  504,
      503,  502,  501,  500,  499,  498,  497,  496,  495,  494,
      493,  492,  491,  490,  489,  488,  487,  486,  485,  484,
      483,  482,  481,  480,  479,  478,  477,  476,  475,  474,
      473,  472,  471,  470,  469,  468,  467,  466,  465,  464,
      463,  462,  461,  460,  459,  458,  457,  456,  455,  454,
      453,  452,  451,  450,  449,  448,  447,  446,  445,  444,
      443,  442,  441,  440,  439,  438,  437,  436,  435,  434,

      433,  432,  431,  430,  429,  428,  427,  426,  425,  424,
      423,  422,  421,  420,  419,  418,  417,  416,  415,  414,
      413,  412,  411,  410,  409,  408,  407,  406,  405,  404,
      401,  400,  399,  398,  397,  396,  395,  394,  393,  392,
      391,  390,  389,  388,  387,  386,  385,  384,  383,  382,
      381,  380,  379,  378,  377,  376,  375,  374,  373,  372,
      371,  370,  369,  368,  367,  366,  365,  364,  363,  362,
      361,  360,  359,  358,  357,  356,  355,  354,  353,  352,
      351,  350,  349,  348,  347,  346,  345,  344,  343,  342,
      341,  340,  336,  335,  334,  331,  330,  327,  326,  325,

      324,  323,  322,  321,  320,  319,  316,  315,  312,  309,
      308,  307,  306,  305,  304,  303,  302,  301,  300,  299,
      295,  294,  293,  292,  291,  290,  289,  286,  285,  284,
      283,  282,  281,  280,  279,  278,  277,  276,  275,  264,
      263,  262,  252,  249,  248,  247,  246,  245,  244,  243,
      242,  241,  240,  239,  238,  234,  225,  224,  223,  222,
      221,  220,  219,  218,  217,  216,  215,  214,  213,  212,
      211,  208,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  198,  197,  196,  195,  194,  193,  192,  191,  190,
      189,  188,  187,  186,  185,  184,  183,  182,  181,  180,

      179,  178,  177,  176,  175,  174,  171,  170,  169,  168,
      167,  166,  165,  164,  163,  162,  161,  160,  159,  158,
      157,  156,  155,  154,  153,  152,  151,  150,  149,  148,
      147,  146,  145,  144,  143,  142,  141,  140,  139,  138,
      137,  136,  135,  134,  133,  132,  131,  130,  129,  128,
      125,  124,  123,  122,  121,  120,  119,  118,  117,  116,
      115,  114,  113,  108,  107,  106,  103,  102,  101,  100,
       99,   98,   97,   94,   93,   92,   91,   85,   84,   83,
       82,   81,   80,   79,   78,   38,   39,   36,   34,   76,
       69,   65,   58,   44,   43,   42,   39,   36,   34,  850,

        3,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      850,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      850,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      850,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      850,  850,  850,  850,  850,  850,  850,  850,  850,  850
    } ;

static yyconst flex_int16_t yy_chk[951] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,   10,
       10,   10,   10,   10,   10,   11,   11,   11,   11,   11,
       11,  176,  176,   11,   12,   12,   12,   12,   12,   12,
       16,   17,   16,   18,   21,   24,   16,   19,   16,   17,
       18,   19,   23,   26,  603,   90,   24,   26,   23,   90,
       19,   21,   18,   30,   29,   29,  253,  604,  253,   30,

       26,   29,   30,   40,   40,   40,   40,   40,   40,   54,
       54,   59,  138,   68,   59,   72,  196,  138,  209,   54,
      605,  196,   54,   68,   54,  196,  212,   72,  250,   72,
       72,  194,  237,  229,  194,  194,  237,  209,  194,  229,
      211,  194,  237,  212,  211,  194,  211,  250,  194,  211,
      256,  211,  194,  266,  211,  211,  216,  606,  607,  216,
      269,  216,  216,  266,  216,  256,  269,  216,  273,  462,
      486,  608,  216,  216,  216,  273,  216,  486,  341,  553,
      273,  341,  474,  474,  474,  609,  462,  611,  553,  613,
      614,  615,  616,  617,  618,  619,  620,  621,  622,  623,

      624,  625,  626,  627,  628,  629,  630,  631,  632,  633,
      634,  630,  635,  636,  637,  638,  639,  640,  641,  642,
      643,  644,  645,  646,  647,  648,  649,  651,  652,  653,
      654,  655,  657,  658,  659,  660,  662,  664,  665,  666,
      667,  668,  669,  670,  673,  674,  676,  677,  678,  679,
      680,  681,  682,  683,  684,  686,  687,  688,  690,  691,
      693,  694,  695,  696,  698,  699,  700,  701,  702,  704,
      705,  706,  707,  709,  710,  711,  712,  713,  715,  716,
      717,  718,  720,  721,  723,  726,  727,  728,  729,  730,
      731,  732,  733,  715,  734,  735,  736,  737,  738,  739,

      740,  741,  743,  745,  746,  747,  748,  749,  750,  751,
      752,  753,  754,  755,  758,  759,  760,  761,  762,  764,
      765,  766,  767,  768,  769,  770,  772,  774,  776,  777,
      778,  779,  781,  782,  783,  784,  785,  786,  787,  790,
      791,  792,  793,  794,  796,  797,  798,  799,  800,  801,
      802,  804,  805,  806,  808,  809,  810,  811,  813,  814,
      816,  817,  820,  821,  822,  823,  824,  825,  826,  827,
      828,  829,  830,  831,  832,  833,  834,  835,  836,  838,
      839,  840,  841,  842,  844,  845,  846,  847,  848,  851,
      851,  851,  851,  852,  853,  602,  853,  853,  854,  854,

      855,  855,  601,  600,  599,  598,  597,  596,  595,  594,
      593,  591,  590,  589,  588,  587,  586,  585,  584,  583,
      582,  581,  580,  579,  578,  577,  576,  575,  574,  573,
      572,  571,  570,  569,  568,  567,  566,  564,  563,  562,
      561,  560,  559,  558,  557,  556,  555,  554,  552,  551,
      550,  549,  548,  547,  546,  545,  544,  543,  542,  541,
      540,  539,  538,  537,  536,  533,  532,  531,  530,  529,
      528,  527,  526,  525,  524,  523,  522,  521,  520,  519,
      518,  517,  516,  514,  513,  512,  511,  510,  508,  507,
      506,  505,  504,  503,  502,  501,  500,  499,  498,  497,

      495,  493,  492,  491,  490,  489,  488,  487,  485,  483,
      482,  481,  480,  479,  478,  476,  475,  473,  472,  471,
      470,  469,  467,  466,  465,  464,  463,  461,  460,  459,
      458,  457,  456,  455,  454,  453,  452,  451,  449,  448,
      447,  446,  445,  444,  441,  440,  438,  437,  436,  433,
      432,  431,  430,  429,  428,  427,  426,  425,  424,  423,
      421,  420,  419,  418,  417,  416,  415,  414,  412,  411,
      408,  407,  406,  404,  403,  402,  401,  400,  399,  398,
      397,  396,  395,  394,  393,  392,  391,  390,  389,  388,
      387,  386,  385,  383,  382,  381,  380,  379,  378,  377,

      376,  375,  374,  372,  370,  367,  366,  365,  364,  363,
      362,  361,  360,  359,  358,  357,  356,  355,  354,  353,
      352,  351,  350,  349,  348,  347,  346,  344,  343,  342,
      340,  339,  338,  337,  336,  335,  334,  333,  332,  331,
      330,  329,  328,  327,  326,  325,  324,  323,  322,  321,
      320,  319,  318,  317,  316,  315,  314,  313,  310,  308,
      306,  305,  303,  302,  301,  300,  299,  298,  297,  296,
      295,  294,  293,  292,  291,  290,  289,  288,  287,  286,
      285,  284,  283,  282,  281,  280,  279,  278,  277,  276,
      275,  274,  272,  271,  270,  268,  267,  265,  264,  263,

      262,  261,  260,  259,  258,  257,  255,  254,  252,  249,
      248,  247,  246,  245,  243,  242,  241,  240,  239,  238,
      236,  235,  234,  233,  232,  231,  230,  228,  227,  226,
      225,  224,  223,  222,  221,  220,  219,  218,  217,  215,
      214,  213,  210,  208,  207,  206,  205,  204,  203,  202,
      201,  200,  199,  198,  197,  195,  193,  192,  191,  190,
      189,  188,  187,  184,  183,  182,  181,  180,  179,  178,
      177,  175,  174,  173,  172,  171,  170,  169,  167,  166,
      165,  164,  163,  162,  161,  160,  159,  158,  157,  156,
      155,  154,  153,  152,  151,  149,  148,  147,  146,  145,

      144,  143,  142,  141,  140,  139,  137,  136,  135,  133,
      132,  131,  130,  129,  128,  127,  126,  125,  124,  123,
      122,  121,  120,  119,  118,  117,  115,  114,  113,  112,
      111,  110,  109,  108,  107,  106,  105,  104,  102,  101,
      100,   99,   98,   97,   96,   95,   94,   93,   92,   91,
       89,   88,   87,   86,   85,   84,   83,   82,   81,   80,
       76,   75,   73,   71,   70,   69,   67,   66,   64,   63,
       62,   61,   60,   58,   57,   56,   55,   53,   52,   51,
       50,   49,   48,   47,   46,   39,   38,   35,   34,   33,
       27,   25,   20,   15,   14,   13,    9,    7,    5,    3,

      850,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      850,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      850,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      850,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      850,  850,  850,  850,  850,  850,  850,  850,  850,  850
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int QuestLoader_flex_debug;
int QuestLoader_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *QuestLoadertext;
#line 1 "QuestLoader.l"
#line 3 "QuestLoader.l"
#include <stdlib.h>
#include <string.h>
#include "AtumDataLoader.h"
#include "QuestLoader.cpp.h"
#undef YY_INPUT
//#define YY_INPUT(buf,result,max_size) \
//    { \
//    int c = getchar(); \
//    result = (c == EOF) ? YY_NULL : (buf[0] = c, 1); \
//    }

extern int g_line_number_quest;

///////////////////////////////////////////////////////////////////////////////
// 2006-04-18 by cmkwon, Aposterophe(''')가 두개이면 하나를 삭제하는 함수
void DeleteTwoAposterophe(char *io_szString)
{
	int nLen = strlen(io_szString);
	int nInputIndex = 0;
	for(int i=0; i < nLen; i++,nInputIndex++)
	{
		if('\'' == io_szString[i]
			&& i+1 < nLen
			&& '\'' == io_szString[i+1])
		{
			io_szString[nInputIndex] = io_szString[i];
			i++;
			continue;
		}
		io_szString[nInputIndex] = io_szString[i];
	}
	io_szString[nInputIndex] = '\0';
}

#line 992 "<stdout>"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif
    
#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int QuestLoaderlex_destroy (void );

int QuestLoaderget_debug (void );

void QuestLoaderset_debug (int debug_flag  );

YY_EXTRA_TYPE QuestLoaderget_extra (void );

void QuestLoaderset_extra (YY_EXTRA_TYPE user_defined  );

FILE *QuestLoaderget_in (void );

void QuestLoaderset_in  (FILE * in_str  );

FILE *QuestLoaderget_out (void );

void QuestLoaderset_out  (FILE * out_str  );

yy_size_t QuestLoaderget_leng (void );

char *QuestLoaderget_text (void );

int QuestLoaderget_lineno (void );

void QuestLoaderset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int QuestLoaderwrap (void );
#else
extern int QuestLoaderwrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( QuestLoadertext, QuestLoaderleng, 1, QuestLoaderout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( QuestLoaderin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( QuestLoaderin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, QuestLoaderin))==0 && ferror(QuestLoaderin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(QuestLoaderin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int QuestLoaderlex (void);

#define YY_DECL int QuestLoaderlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after QuestLoadertext and QuestLoaderleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 39 "QuestLoader.l"

#line 1176 "<stdout>"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! QuestLoaderin )
			QuestLoaderin = stdin;

		if ( ! QuestLoaderout )
			QuestLoaderout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			QuestLoaderensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				QuestLoader_create_buffer(QuestLoaderin,YY_BUF_SIZE );
		}

		QuestLoader_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of QuestLoadertext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 851 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 901 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 40 "QuestLoader.l"
return QUEST_TOK;
	YY_BREAK
/* BASIC_INFO 관련 */
case 2:
YY_RULE_SETUP
#line 43 "QuestLoader.l"
{
							_loader_print("	BASIC_INFO_TOK\n");
							return BASIC_INFO_TOK;
						}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 47 "QuestLoader.l"
return QUEST_INDEX_TOK;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 48 "QuestLoader.l"
return QUEST_NAME_TOK;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 49 "QuestLoader.l"
return QUEST_EPISODE_TYPE_TOK;	// 2008-06-16 by cmkwon, EP3 퀘스트 기존 퀘스트와 구별 - 
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 50 "QuestLoader.l"
return QUEST_PARTYTYPE_TOK;	// 2008-12-02 by dhjin, 미션마스터
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 51 "QuestLoader.l"
return QUEST_KIND_TOK;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 52 "QuestLoader.l"
return QUEST_TYPE_TOK;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 53 "QuestLoader.l"
return QUEST_START_TYPE_TOK;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 54 "QuestLoader.l"
return QUEST_END_TYPE_TOK;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 55 "QuestLoader.l"
return QUEST_PARTY_MEMBERS_TOK;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 56 "QuestLoader.l"
return QUEST_NPC_INFO_TOK;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 57 "QuestLoader.l"
return NPC_INDEX_TOK;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 58 "QuestLoader.l"
return NPC_NAME_TOK;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 59 "QuestLoader.l"
return PRE_TALK_TOK;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 60 "QuestLoader.l"
return MID_TALK_TOK;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 61 "QuestLoader.l"
return FAIL_TALK_TOK;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 62 "QuestLoader.l"
return SUCCESS_TALK_TOK;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 63 "QuestLoader.l"
return DESCRIPTION_TOK;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 64 "QuestLoader.l"
return EVENT_MAP_TOK;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 65 "QuestLoader.l"
return NEXT_QUEST_INDEX_TOK;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 66 "QuestLoader.l"
return PARTY_QUEST_MEMBER_COUNT_TOK;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 67 "QuestLoader.l"
return DROP_ITEM_TO_ALL_ATTACK_CHARACTER_TOK;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 68 "QuestLoader.l"
return TIME_LIMIT_IN_MINUTES_TOK;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 69 "QuestLoader.l"
return DISCARDABLE_QUEST_TOK;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 70 "QuestLoader.l"
return BI_QUEST_ATTRI_IS_CITYWAR_TOK;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 71 "QuestLoader.l"
return BI_QUEST_ATTRI_NEVER_COMPLETION_BY_USER_TOK;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 72 "QuestLoader.l"
return DROP_ITEM_TO_ALL_PARTY_MEMBERS_TOK;	// 2009-01-13 by cmkwon, 미션 보상을 파티원 모두에게 주기 명령어 추가 - 
	YY_BREAK
/* START_REQ 관련 */
case 29:
YY_RULE_SETUP
#line 75 "QuestLoader.l"
{
							_loader_print("	START_REQ_TOK\n");
							return START_REQ_TOK;
						}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 79 "QuestLoader.l"
return S_REQ_UNIT_KIND_TOK;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 80 "QuestLoader.l"
return S_REQ_LEVEL_TOK;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 81 "QuestLoader.l"
return S_REQ_ATTACK_PART_TOK;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 82 "QuestLoader.l"
return S_REQ_DEFENSE_PART_TOK;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 83 "QuestLoader.l"
return S_REQ_FUEL_PART_TOK;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 84 "QuestLoader.l"
return S_REQ_SOUL_PART_TOK;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 85 "QuestLoader.l"
return S_REQ_SHIELD_PART_TOK;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 86 "QuestLoader.l"
return S_REQ_DODGE_PART_TOK;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 87 "QuestLoader.l"
return S_REQ_ITEM_TOK;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 88 "QuestLoader.l"
return S_REQ_QUEST_INDEX_TOK;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 89 "QuestLoader.l"
return S_REQ_RECV_QUEST_INDEX_TOK;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 90 "QuestLoader.l"
return S_REQ_GUILD_TOK;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 91 "QuestLoader.l"
return S_REQ_INFLUENCE_TYPE_TOK;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 92 "QuestLoader.l"
return S_REQ_START_AREA_TOK;
	YY_BREAK
/* START_ACTION  관련 */
case 44:
YY_RULE_SETUP
#line 95 "QuestLoader.l"
{
							_loader_print("	START_ACTION_TOK\n");
							return START_ACTION_TOK;
						}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 99 "QuestLoader.l"
return S_PAY_ITEM_TOK;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 100 "QuestLoader.l"
return S_DEL_ITEM_TOK;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 101 "QuestLoader.l"
return S_START_MAP_INDEX_TOK;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 102 "QuestLoader.l"
return S_START_PARTY_WARP_FLAG_TOK;
	YY_BREAK
/* COMPLETION_REQ 관련 */
case 49:
YY_RULE_SETUP
#line 105 "QuestLoader.l"
{
							_loader_print("	COMPLETION_REQ_TOK\n");
							return COMPLETION_REQ_TOK;
						}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 109 "QuestLoader.l"
return C_REQ_MEET_NPC_INFO_TOK;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 110 "QuestLoader.l"
return C_REQ_ITEM_TOK;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 111 "QuestLoader.l"
return C_REQ_MEET_OBJ_INDEX_TOK;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 112 "QuestLoader.l"
return C_REQ_DEAD_BY_MONSTER_TOK;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 113 "QuestLoader.l"
return C_REQ_MEET_MAP_AREA_TOK;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 114 "QuestLoader.l"
return C_REQ_MONSTER_TOK;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 115 "QuestLoader.l"
return C_REQ_MIX_ITEM_TARGET_TOK;
	YY_BREAK
/* COMPLETION_ACTION 관련 */
case 57:
YY_RULE_SETUP
#line 118 "QuestLoader.l"
{
							_loader_print("	COMPLETION_ACTION_TOK\n");
							return COMPLETION_ACTION_TOK;
						}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 122 "QuestLoader.l"
return C_PAY_BONUS_STAT_TOK;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 123 "QuestLoader.l"
return C_PAY_BONUS_SKILL_POINT_TOK;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 124 "QuestLoader.l"
return C_PAY_FAME_TOK;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 125 "QuestLoader.l"
return C_PAY_STATUS_TOK;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 126 "QuestLoader.l"
return C_PAY_LEVEL_TOK;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 127 "QuestLoader.l"
return C_PAY_EXPERIENCE_TOK;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 128 "QuestLoader.l"
return C_PAY_WARP_MAP_INDEX_TOK;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 129 "QuestLoader.l"
return C_DEL_ITEM_TOK;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 130 "QuestLoader.l"
return C_PAY_ITEM_TOK;   
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 131 "QuestLoader.l"
return C_PAY_ITEM_MISSIONMASTER_TOK;	// 2008-12-02 by dhjin, 미션마스터
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 132 "QuestLoader.l"
return C_RANDOM_PAY_ITEM_TOK;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 133 "QuestLoader.l"
return C_MIX_ITEM_TOK;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 134 "QuestLoader.l"
return C_PAY_PROPENSITY_TOK;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 135 "QuestLoader.l"
return C_CINEMA_NUM_TOK;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 136 "QuestLoader.l"
return C_PAY_INFLUENCE_TYPE_TOK;
	YY_BREAK
/* 범용 Token */
case 73:
YY_RULE_SETUP
#line 139 "QuestLoader.l"
return FROM_TOK;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 140 "QuestLoader.l"
return TO_TOK;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 141 "QuestLoader.l"
return MONSTER_TOK;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 142 "QuestLoader.l"
return CHARACTER_TOK;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 143 "QuestLoader.l"
return ALL_TOK;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 144 "QuestLoader.l"
return ATTACH_TOK;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 145 "QuestLoader.l"
return AREA_TOK;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 146 "QuestLoader.l"
return X_TOK;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 147 "QuestLoader.l"
return Y_TOK;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 148 "QuestLoader.l"
return R_TOK;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 149 "QuestLoader.l"
return PER_TOK;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 151 "QuestLoader.l"
return PROB_100_TOK;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 152 "QuestLoader.l"
return PROB_1K_TOK;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 153 "QuestLoader.l"
return PROB_10K_TOK;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 154 "QuestLoader.l"
return PROB_100K_TOK;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 155 "QuestLoader.l"
return PROB_256_TOK;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 157 "QuestLoader.l"
return AND_TOK;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 158 "QuestLoader.l"
return OR_TOK;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 160 "QuestLoader.l"
return TRUE_TOK;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 161 "QuestLoader.l"
return FALSE_TOK;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 163 "QuestLoader.l"
return R_ARROW_TOK;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 164 "QuestLoader.l"
return GT_TOK;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 165 "QuestLoader.l"
return LT_TOK;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 166 "QuestLoader.l"
return GE_TOK;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 167 "QuestLoader.l"
return LE_TOK;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 168 "QuestLoader.l"
return EQUAL_TOK;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 169 "QuestLoader.l"
{
								strncpy(QuestLoaderlval.string2048, QuestLoadertext, 2048);
								_loader_print("	USER_VARIABLE_TOK: %s\n", QuestLoaderlval.string2048);
								return USER_VARIABLE_TOK;
							}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 174 "QuestLoader.l"
{
							QuestLoaderlval.integer = atoi(QuestLoadertext);
							_loader_print("	INTEGER_TOK: %d\n", QuestLoaderlval.integer);
							return INTEGER_TOK;
						}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 179 "QuestLoader.l"
{
							strncpy(QuestLoaderlval.string2048, QuestLoadertext, 2048);
							_loader_print("	WORD_TOK: %s\n", QuestLoaderlval.string2048);
							return WORD_TOK;
						}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 184 "QuestLoader.l"
{
							strncpy(QuestLoaderlval.string2048, QuestLoadertext + 1, 2048);
							QuestLoaderlval.string2048[strlen(QuestLoaderlval.string2048)-1] = '\0';
							DeleteTwoAposterophe(QuestLoaderlval.string2048);
							_loader_print("	QSTRING_TOK: %s\n", QuestLoaderlval.string2048);
							return QSTRING_TOK;
						}
	YY_BREAK
case 103:
/* rule 103 can match eol */
YY_RULE_SETUP
#line 191 "QuestLoader.l"
{ /* ignore EOL */;	g_line_number_quest++; }
	YY_BREAK
case 104:
*yy_cp = (yy_hold_char); /* undo effects of setting up QuestLoadertext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up QuestLoadertext again */
YY_RULE_SETUP
#line 192 "QuestLoader.l"
{ /* ignore comment */; /*_loader_print("	comment line %d\n", g_line_number_quest);*/ }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 193 "QuestLoader.l"
/* ignore whitespace */;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 194 "QuestLoader.l"
return QuestLoadertext[0];
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 195 "QuestLoader.l"
ECHO;
	YY_BREAK
#line 1837 "<stdout>"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed QuestLoaderin at a new source and called
			 * QuestLoaderlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = QuestLoaderin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( QuestLoaderwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * QuestLoadertext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of QuestLoaderlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					QuestLoaderrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			QuestLoaderrestart(QuestLoaderin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) QuestLoaderrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 851 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 851 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 850);

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up QuestLoadertext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					QuestLoaderrestart(QuestLoaderin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( QuestLoaderwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve QuestLoadertext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void QuestLoaderrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        QuestLoaderensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            QuestLoader_create_buffer(QuestLoaderin,YY_BUF_SIZE );
	}

	QuestLoader_init_buffer(YY_CURRENT_BUFFER,input_file );
	QuestLoader_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void QuestLoader_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		QuestLoaderpop_buffer_state();
	 *		QuestLoaderpush_buffer_state(new_buffer);
     */
	QuestLoaderensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	QuestLoader_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (QuestLoaderwrap()) processing, but the only time this flag
	 * is looked at is after QuestLoaderwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void QuestLoader_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	QuestLoaderin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE QuestLoader_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) QuestLoaderalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in QuestLoader_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) QuestLoaderalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in QuestLoader_create_buffer()" );

	b->yy_is_our_buffer = 1;

	QuestLoader_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with QuestLoader_create_buffer()
 * 
 */
    void QuestLoader_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		QuestLoaderfree((void *) b->yy_ch_buf  );

	QuestLoaderfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a QuestLoaderrestart() or at EOF.
 */
    static void QuestLoader_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	QuestLoader_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then QuestLoader_init_buffer was _probably_
     * called from QuestLoaderrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void QuestLoader_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		QuestLoader_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void QuestLoaderpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	QuestLoaderensure_buffer_stack();

	/* This block is copied from QuestLoader_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from QuestLoader_switch_to_buffer. */
	QuestLoader_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void QuestLoaderpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	QuestLoader_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		QuestLoader_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void QuestLoaderensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)QuestLoaderalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in QuestLoaderensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)QuestLoaderrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in QuestLoaderensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE QuestLoader_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) QuestLoaderalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in QuestLoader_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	QuestLoader_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to QuestLoaderlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       QuestLoader_scan_bytes() instead.
 */
YY_BUFFER_STATE QuestLoader_scan_string (yyconst char * yystr )
{
    
	return QuestLoader_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to QuestLoaderlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE QuestLoader_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) QuestLoaderalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in QuestLoader_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = QuestLoader_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in QuestLoader_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up QuestLoadertext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		QuestLoadertext[QuestLoaderleng] = (yy_hold_char); \
		(yy_c_buf_p) = QuestLoadertext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		QuestLoaderleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int QuestLoaderget_lineno  (void)
{
        
    return QuestLoaderlineno;
}

/** Get the input stream.
 * 
 */
FILE *QuestLoaderget_in  (void)
{
        return QuestLoaderin;
}

/** Get the output stream.
 * 
 */
FILE *QuestLoaderget_out  (void)
{
        return QuestLoaderout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t QuestLoaderget_leng  (void)
{
        return QuestLoaderleng;
}

/** Get the current token.
 * 
 */

char *QuestLoaderget_text  (void)
{
        return QuestLoadertext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void QuestLoaderset_lineno (int  line_number )
{
    
    QuestLoaderlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see QuestLoader_switch_to_buffer
 */
void QuestLoaderset_in (FILE *  in_str )
{
        QuestLoaderin = in_str ;
}

void QuestLoaderset_out (FILE *  out_str )
{
        QuestLoaderout = out_str ;
}

int QuestLoaderget_debug  (void)
{
        return QuestLoader_flex_debug;
}

void QuestLoaderset_debug (int  bdebug )
{
        QuestLoader_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from QuestLoaderlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    QuestLoaderin = stdin;
    QuestLoaderout = stdout;
#else
    QuestLoaderin = (FILE *) 0;
    QuestLoaderout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * QuestLoaderlex_init()
     */
    return 0;
}

/* QuestLoaderlex_destroy is for both reentrant and non-reentrant scanners. */
int QuestLoaderlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		QuestLoader_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		QuestLoaderpop_buffer_state();
	}

	/* Destroy the stack itself. */
	QuestLoaderfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * QuestLoaderlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *QuestLoaderalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *QuestLoaderrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void QuestLoaderfree (void * ptr )
{
	free( (char *) ptr );	/* see QuestLoaderrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 194 "QuestLoader.l"



